﻿using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;

namespace SimpleGrid
{
	public partial class SimpleGridViewController : UIViewController
	{
		#region Members

		IGGridView gridView;

		IGGridViewDataSourceHelper dsh;

		List<cSimpleGrid> lstGridItems;

		public int mPage = 1;

		public int mTotalRecords;

		#endregion

		#region Constructor

		public SimpleGridViewController () : base ("SimpleGridViewController", null)
		{
		}

		#endregion

		#region View Controller Methods

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			//Next, create a new instance of the grid view and place it on the view.
			gridView = new IGGridView (new System.Drawing.RectangleF (0, 0, this.View.Bounds.Width, this.View.Bounds.Height), IGGridViewStyle.IGGridViewStyleDefault);
			gridView.AutoresizingMask = UIViewAutoresizing.All;

			this.View.Add (gridView);


			// create some objects and fill a list
			cSimpleGrid obj1 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj2 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj3 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj4 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj5 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj6 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj7 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj8 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj9 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj10 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
			cSimpleGrid obj11 = new cSimpleGrid () { Motion = 1, Left = 2, Right = 3 };
	



			lstGridItems = new List<cSimpleGrid>(new cSimpleGrid[]{ obj1, obj2, obj3, obj4, obj5, obj6, obj7, obj8, obj9, obj10, obj11 });



			//Setup the Grid
			SetupGrid ();
		}

		#endregion

		#region Methods

		/// <summary>
		/// This method is responsible for the layour and populate of the grid view
		/// </summary>
		private bool SetupGrid ()
		{
			//First, create a new return variable
			bool bReturn = true;

			try {

				// We're using the basic IGGridViewDataSourceHelper
				// since our data will be displayed in a standard datagrid
				dsh = new IGGridViewDataSourceHelper();

				// Since we are manually creating columns, turn off auto-generation
				dsh.AutoGenerateColumns = false;


				IGGridViewColumnDefinition motion = new IGGridViewColumnDefinition("Motion");
				IGGridViewColumnDefinition left = new IGGridViewColumnDefinition("Left");
				IGGridViewColumnDefinition right = new IGGridViewColumnDefinition("Right");

				dsh.ColumnDefinitions.Add(motion);
				dsh.ColumnDefinitions.Add(left);
				dsh.ColumnDefinitions.Add(right);
			
				gridView.Delegate = new gridViewDelegate(this);
				dsh.LoadMoreDelegate = new LoadMoreHelper(gridView, this);

				//Next, set the data object
				dsh.Data = lstGridItems.ToArray();

				dsh.AllowEditing = true;

				//Set the DataSource
				gridView.DataSource = dsh;

				gridView.RowReordering = true;

				//Turn off empty rows
				gridView.EmptyRows = false;

				//Update gridView
				gridView.UpdateData ();

			} catch {
				//Error building the grid, return false.
				bReturn = false;
			}

			//Finally, return the return variable
			return bReturn;
		}

		#endregion

		#region Specialized Classes

		#region Helpers

		public class LoadMoreHelper : IGGridViewDataSourceHelperLoadMoreDelegate
		{
			#region Members

			IGGridView gridView;
			SimpleGridViewController mClinicNavigatorViewController;

			#endregion

			#region Constructor

			public LoadMoreHelper (IGGridView GridView, SimpleGridViewController clinicNavigatorViewController)
			{
				gridView = GridView;
				mClinicNavigatorViewController = clinicNavigatorViewController;
			}

			#endregion

			#region Data Source Helper Methods

			public override IGGridViewLoadMoreCell ResolveLoadMoreCell (IGGridView gridView)
			{
				IGGridViewLoadMoreCell cell = (IGGridViewLoadMoreCell)gridView.DequeueReusableCell ("LoadMore");

				return cell;
			}

			public override bool NeedMoreRows (IGGridViewDataSourceHelper dataSource)
			{
				return dataSource.Data.Length < 100;
			}

			public override void LoadMoreRows (IGGridViewDataSourceHelper dataSource)
			{
				mClinicNavigatorViewController.mPage++;

				if (mClinicNavigatorViewController.lstGridItems.Count > 0) {
					mClinicNavigatorViewController.lstGridItems.InsertRange (mClinicNavigatorViewController.lstGridItems.Count, LoadMorePendingDocuments ());

					//Rebind the datasource
					dataSource.Data = mClinicNavigatorViewController.lstGridItems.ToArray ();

					//Update the display
					gridView.UpdateData ();
				}
			}

			#endregion

			#region Methods

			private List<cSimpleGrid> LoadMorePendingDocuments ()
			{

			
				// create some objects and fill a list
				cSimpleGrid obj1 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj2 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj3 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj4 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj5 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj6 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj7 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj8 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj9 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33 };
				cSimpleGrid obj10 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 333 };
				cSimpleGrid obj11 = new cSimpleGrid () { Motion = 11, Left = 22, Right = 33};




				List<cSimpleGrid> lstGridItems = new List<cSimpleGrid>(new cSimpleGrid[]{ obj1, obj2, obj3, obj4, obj5, obj6, obj7, obj8, obj9, obj10, obj11 });


				return lstGridItems;

			}

			#endregion
		}
		#endregion

		public class gridViewDelegate : IGGridViewDelegate
		{
			#region Members

			UIPopoverController mPc;
			SimpleGridViewController controller;
			public UIButton mSortOrderButton;
			public UIButton mSortColumnButton;
			UIView mSectionHeaderView;

			#endregion

			#region Constructor

			public gridViewDelegate (SimpleGridViewController controller)
			{
				this.controller = controller;
			}

			#endregion

			#region Override Methods

			public override UIView ResolveSectionHeaderView (IGGridView gridView, int section)
			{
				if (mSectionHeaderView == null) {
					mSectionHeaderView = new UIView ();

					mSectionHeaderView.BackgroundColor = UIColor.FromRGB (224, 224, 224);

					mSortColumnButton = new UIButton (UIButtonType.Custom);
					mSortColumnButton.Frame = new RectangleF (0, 0, 100, 30);
					mSortColumnButton.SetTitle ("Sort By", UIControlState.Normal);

					mSortColumnButton.SetTitleColor (UIColor.Blue, UIControlState.Normal);
				

					mSortOrderButton = new UIButton (UIButtonType.Custom);
					mSortOrderButton.Frame = new RectangleF (110, 0, 100, 30);
					mSortOrderButton.SetTitle ("Order By", UIControlState.Normal);

					mSortOrderButton.SetTitleColor (UIColor.Blue, UIControlState.Normal);


					mSectionHeaderView.Add (mSortColumnButton);
					mSectionHeaderView.Add (mSortOrderButton);
				} 

				return mSectionHeaderView;
			}
			#endregion


		}


	
		#endregion

	
	}
}

